==> redssh-1.2.0.tar.gz: redssh-1.2.0/setup.py <==
# RedSSH
# Copyright (C) 2018  Red_M ( http://bitbucket.com/Red_M )

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

with open('VERSION', 'r') as fh:
    redssh_version = fh.read()


deps = [
    'ssh2-python'
]

doc_deps = [
    'paramiko',
    'sphinx',
    'sphinx_rtd_theme'
]


setuptools.setup(
    name='redssh',
    version=redssh_version,
    url='https://bitbucket.org/Red_M/RedSSH',
    license='GPLv2',
    author='Red_M',
    author_email='redssh_pypi@red-m.net',
    description='An SSH automation library.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    platforms='Posix',
    install_requires=deps,
    extras_require={
        'tests':deps+doc_deps,
        'docs':deps+doc_deps
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Intended Audience :: Developers'
    ],
)

==> redssh-2.0.0.tar.gz: redssh-2.0.0/setup.py <==
# RedSSH
# Copyright (C) 2019  Red_M ( http://bitbucket.com/Red_M )

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

with open('VERSION', 'r') as fh:
    redssh_version = fh.read()


deps = [
    'ssh2-python'
]

doc_deps = [
    'paramiko',
    'sphinx',
    'sphinx_rtd_theme'
]


setuptools.setup(
    name='redssh',
    version=redssh_version,
    url='https://bitbucket.org/Red_M/RedSSH',
    license='GPLv2',
    author='Red_M',
    author_email='redssh_pypi@red-m.net',
    description='An SSH automation library.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    platforms='Posix',
    install_requires=deps,
    extras_require={
        'tests':deps+doc_deps,
        'docs':deps+doc_deps
    },
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Intended Audience :: Developers'
    ],
)
